assets

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2025 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// FileReadPerm is the permission bit given to the OS when reading files.
	FileReadPerm = 0o600
	// DirPerm is the permission bit given to teamserver/client directories.
	DirPerm = 0o700
	// FileWritePerm is the permission bit given to the OS when writing files.
	FileWritePerm = 0o644

	// FileWriteOpenMode is used when opening log files in append/create/write-only mode.
	FileWriteOpenMode = os.O_APPEND | os.O_CREATE | os.O_WRONLY
)
const (

	// DirClient is the name of the teamclient subdirectory.
	DirClient = "teamclient"
	// DirLogs subdirectory name.
	DirLogs = "logs"
	// DirConfigs subdirectory name.
	DirConfigs = "configs"

	// DirServer is the name of the teamserver subdirectory.
	DirServer = "teamserver"
	// DirCerts subdirectory name.
	DirCerts = "certs"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type FS

type FS = afero.Afero

FS is a filesystem abstraction for teamservers and teamclients. When either of them are configured to run in memory only, this filesystem is initialized accordingly, otherwise it will forward its calls to the on-disk filesystem.

func NewFileSystem

func NewFileSystem(inMemory bool) *FS

NewFileSystem returns a new filesystem configured to run on disk or in-memory.

Jump to